==> pdal_1.2.0.orig.tar.bz2: PDAL-1.2.0-src/plugins/hexbin/kernel/OGR.hpp <==
/******************************************************************************
* Copyright (c) 2016, Howard Butler (howard@hobu.co)
*
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following
* conditions are met:
*
*     * Redistributions of source code must retain the above copyright
*       notice, this list of conditions and the following disclaimer.
*     * Redistributions in binary form must reproduce the above copyright
*       notice, this list of conditions and the following disclaimer in
*       the documentation and/or other materials provided
*       with the distribution.
*     * Neither the name of Hobu, Inc. or Flaxen Geo Consulting nor the
*       names of its contributors may be used to endorse or promote
*       products derived from this software without specific prior
*       written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
* "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
* LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
* FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
* COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
* INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
* BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
* OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
* AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
* OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
* OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
* OF SUCH DAMAGE.
****************************************************************************/
#pragma once

#include <hexer/hexer.hpp>

#include <hexer/Processor.hpp>

#include <hexer/hexer_defines.h>
#include <hexer/Mathpair.hpp>
#include <hexer/HexInfo.hpp>
#include <hexer/export.hpp>
#include <pdal/pdal_macros.hpp>



#include "ogr_api.h"
#include "gdal.h"

namespace pdal
{
namespace hexdensity
{


namespace writer
{


class OGR
{


public:
    OGR(std::string const& filename, std::string srs, std::string driver = "ESRI Shapefile");
    ~OGR();

    void writeBoundary(hexer::HexGrid *grid);
    void writeDensity(hexer::HexGrid *grid);

private:
    std::string m_filename;
    std::string m_driver;
    std::string m_srs;

    OGRDataSourceH m_ds;
    OGRLayerH m_layer;

    void createLayer();
    void collectPath(hexer::Path* path, OGRGeometryH polygon);
    OGRGeometryH collectHexagon(hexer::HexInfo const& info, hexer::HexGrid const* grid);

};

} // writer

} // namespace

} //pdal

==> pdal_1.7.2.orig.tar.bz2: PDAL-1.7.2-src/plugins/hexbin/kernel/OGR.hpp <==
/******************************************************************************
* Copyright (c) 2016, Howard Butler (howard@hobu.co)
*
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following
* conditions are met:
*
*     * Redistributions of source code must retain the above copyright
*       notice, this list of conditions and the following disclaimer.
*     * Redistributions in binary form must reproduce the above copyright
*       notice, this list of conditions and the following disclaimer in
*       the documentation and/or other materials provided
*       with the distribution.
*     * Neither the name of Hobu, Inc. or Flaxen Geo Consulting nor the
*       names of its contributors may be used to endorse or promote
*       products derived from this software without specific prior
*       written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
* "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
* LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
* FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
* COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
* INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
* BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
* OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
* AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
* OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
* OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY
* OF SUCH DAMAGE.
****************************************************************************/
#pragma once

#include <hexer/hexer.hpp>
#include <hexer/Processor.hpp>
#include <hexer/hexer_defines.h>
#include <hexer/Mathpair.hpp>
#include <hexer/HexInfo.hpp>
#include <hexer/export.hpp>

#include "ogr_api.h"
#include "gdal.h"

namespace pdal
{
namespace hexdensity
{
namespace writer
{


class OGR
{


public:
    OGR(std::string const& filename, std::string srs, std::string driver = "ESRI Shapefile", std::string layerName ="");
    ~OGR();

    void writeBoundary(hexer::HexGrid *grid);
    void writeDensity(hexer::HexGrid *grid);

private:
    std::string m_filename;
    std::string m_driver;
    std::string m_srs;

    OGRDataSourceH m_ds;
    OGRLayerH m_layer;
    std::string m_layerName;

    void createLayer();
    void collectPath(hexer::Path* path, OGRGeometryH polygon);
    OGRGeometryH collectHexagon(hexer::HexInfo const& info, hexer::HexGrid const* grid);

};

} // writer

} // namespace

} //pdal
